call plug#begin('~/.vim/plugged')
Plug 'neoclide/coc.nvim', {'branch': 'release'}
Plug 'powerline/powerline-fonts'
Plug 'vim-airline/vim-airline'
Plug 'vim-airline/vim-airline-themes'
Plug 'posva/vim-vue'
Plug 'jwalton512/vim-blade'
Plug 'junegunn/goyo.vim'
Plug 'junegunn/fzf', { 'do': { -> fzf#install() } }
Plug 'junegunn/fzf.vim'
Plug 'gpanders/editorconfig.nvim'
call plug#end()

" nvim config
syntax on
set number
set nohlsearch
set relativenumber
set tabstop=2 softtabstop=2
set shiftwidth=2
set expandtab
set smartindent
set smartcase
set noswapfile
set undodir=~/.vim/undodir
set undofile
set scrolloff=8
set noshowmode
set winblend=0
set wildoptions=pum
set pumblend=5
set background=dark
syntax enable
set cursorline
hi CursorLine cterm=NONE ctermbg=237 ctermfg=NONE

" give more space for displaying messages
set cmdheight=2

" airline config
let g:airline_powerline_fonts = 1
let g:airline_theme = 'papercolor'

" enable list of buffers
let g:airline#extensions#tabline#enabled = 1
" show just the filename
let g:airline#extensions#tabline#fnamemod = ':t'

""" buffers as tabs config
" allows buffers to be hidden if you modified them
set hidden

" open new empty buffer
nmap <C-T> :enew<CR>

" move to next buffer
nmap <C-L> :bnext<CR>

" move to previous buffer
nmap <C-H> :bprevious<CR>

" close current buffer and move to previous one
nmap <C-Q> :bp <BAR> bd #<CR>

" show all open buffers and their status
nmap <C-B> :ls<CR>

""" autocmds
"autocmd BufWritePost *.md silent !pandoc % -o %:r.pdf
"autocmd BufWritePost *.md !pandoc -N % -o %:r.pdf

" shortcuts
nnoremap <C-G> :Goyo<CR>
" check if git dir, then use :GFiles for fzf
if isdirectory('.git')
  nnoremap <C-P> :GFiles<CR>
else
  nnoremap <C-P> :Files<CR>
endif
